% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/trivPenalNL.R
\name{trivPenalNL}
\alias{trivPenalNL}
\title{Fit a Non-Linear Trivariate Joint Model for Recurrent Events and a Terminal
Event with a Biomarker Described with an ODE Population Model}
\usage{
trivPenalNL(formula, formula.terminalEvent, biomarker, formula.KG,
formula.KD, dose, time.biomarker, data, data.Longi, random, id, link =
"Random-effects", BoxCox = FALSE, left.censoring = FALSE, recurrentAG =
FALSE, n.knots, kappa, maxit = 300, hazard = "Splines", init.B, init.Random,
init.Eta, init.Alpha, init.Biomarker, method.GH = "Standard", init.GH =
FALSE, n.nodes, LIMparam = 1e-3, LIMlogl = 1e-3, LIMderiv = 1e-3,
print.times = TRUE)
}
\arguments{
\item{formula}{a formula object, with the response on the left of a
\eqn{\sim} operator, and the terms on the right. The response must be a
survival object as returned by the 'Surv' function like in survival package.
Interactions are possible using * or :.}

\item{formula.terminalEvent}{A formula object, only requires terms on the
right to indicate which variables are modelling the terminal event.
Interactions are possible using * or :.}

\item{biomarker}{Name of the variable representing the longitudinal
biomarker.}

\item{formula.KG}{A formula object, only requires terms on the right to
indicate which covariates related to the biomarker growth are included in
the longitudinal sub-model.  It must follow the standard form used for
linear mixed-effects models. Interactions are possible using * or :.}

\item{formula.KD}{A formula object, only requires terms on the right to
indicate which covariates related to the biomarker drug-induced decline are
included in the longitudinal sub-model.  It must follow the standard form
used for linear mixed-effects models. Interactions are possible using * or
:.}

\item{dose}{Name of the variable representing the drug concentration
indicator.}

\item{time.biomarker}{Name of the variable of times of biomarker
measurements.}

\item{data}{A 'data.frame' with the variables used in \code{formula}.}

\item{data.Longi}{A 'data.frame' with the variables used in
\code{formula.KG}, \code{formula.KD}, \code{biomarker}, \code{dose},
\code{time.biomarker} and \code{id}.}

\item{random}{Names of parameters for which the random effects are included
in the mixed model. The names must be chosen among \code{"y0"}, \code{"KG"},
\code{"KD"} and \code{"lambda"}. Any combination of the mentioned names is
allowed.}

\item{id}{Name of the variable representing the individuals.}

\item{link}{Type of link functions for the dependence between the biomarker
and death and between the biomarker and the recurrent events: only
\code{"Random-effects"} for the association directly via the random effects
of the biomarker is allowed for the moment (option for a future extension).}

\item{BoxCox}{Should the Box-Cox transformation be used for the longitudinal
biomarker? If there is no transformation, the argument must be equal to
\code{FALSE}, otherwise the of the transformation parameter must be given,
then the transformed values are \eqn{y^*=(y^{\xi}-1)/\xi}, where \eqn{\xi}
is the Box-Cox parameter.}

\item{left.censoring}{Is the biomarker left-censored below a threshold
\eqn{s}? If there is no left-censoring, the argument must be equal to
\code{FALSE}, otherwise the value of the threshold must be given.}

\item{recurrentAG}{Logical value.  Is Andersen-Gill model fitted?  If so
indicates that recurrent event times with the counting process approach of
Andersen and Gill is used. This formulation can be used for dealing with
time-dependent covariates.  The default is FALSE.}

\item{n.knots}{Integer giving the number of knots to use. Value required in
the penalized likelihood estimation.  It corresponds to the (n.knots+2)
splines functions for the approximation of the hazard or the survival
functions.  We estimate I or M-splines of order 4. When the user set a
number of knots equals to k (n.knots=k) then the number of interior knots is
(k-2) and the number of splines is (k-2)+order.  Number of knots must be
between 4 and 20. (See Note in \code{frailtyPenal} function)}

\item{kappa}{Positive smoothing parameters in the penalized likelihood
estimation.  The coefficient kappa of the integral of the squared second
derivative of hazard function in the fit (penalized log likelihood). To
obtain an initial value for \code{kappa}, a solution is to fit the
corresponding Cox model using cross validation (See \code{cross.validation}
in function \code{frailtyPenal}).  We advise the user to identify several
possible tuning parameters, note their defaults and look at the sensitivity
of the results to varying them.}

\item{maxit}{Maximum number of iterations for the Marquardt algorithm.
Default is 300}

\item{hazard}{Type of hazard functions: \code{"Splines"} for semiparametric
hazard functions using equidistant intervals or \code{"Splines-per"} using
percentile with the penalized likelihood estimation, \code{"Weibull"} for
the parametric Weibull functions. The default is \code{"Splines"}.}

\item{init.B}{Vector of initial values for regression coefficients. This
vector should be of the same size as the whole vector of covariates with the
first elements for the covariates related to the recurrent events, then to
the terminal event and then to the biomarker (interactions in the end of
each component). Default is 0.5 for each.}

\item{init.Random}{Initial value for variance of the elements of the matrix
of the distribution of the random effects.}

\item{init.Eta}{Initial values for regression coefficients for the link
functions, first for the recurrent events (\eqn{\bold{\eta}_R}) and for the
terminal event (\eqn{\bold{\eta}_T}).}

\item{init.Alpha}{Initial value for parameter alpha}

\item{init.Biomarker}{Initial values for biomarker parameters: \eqn{y_0},
\eqn{K_{G,0}}, \eqn{K_{D,0}} and \eqn{\lambda} (using this order).}

\item{method.GH}{Method for the Gauss-Hermite quadrature: \code{"Standard"}
for the standard non-adaptive Gaussian quadrature and
\code{"Pseudo-adaptive"} for the pseudo-adaptive Gaussian quadrature (see
Details). The default is \code{"Standard"}.  When the option
\code{"Pseudo-adaptive"} is chosen, then a univariate model (non-linear
mixed model for the biomarker) is fitted in order to obtain the estimations
of the random effects \eqn{\bold{b}_i}.}

\item{init.GH}{Only when the opiton \code{"Pseudo-adaptive"} of the argument
\code{method.GH} is chosen. If \code{TRUE}, the estimations of the biomarker
parameters (\eqn{y_0}, \eqn{K_{G,0}}, \eqn{K_{D,0}} and \eqn{\lambda}),
\eqn{\sigma_{\epsilon}}, \eqn{\bold{\beta}_G} and \eqn{\bold{\beta}_D} from
the univariate mixed model are used as the initial values of the parameters
related to the biomarker.}

\item{n.nodes}{Number of nodes for the Gauss-Hermite quadrature (from 5 to
32). The default is 9.}

\item{LIMparam}{Convergence threshold of the Marquardt algorithm for the
parameters (see Details), \eqn{10^{-3}} by default.}

\item{LIMlogl}{Convergence threshold of the Marquardt algorithm for the
log-likelihood (see Details), \eqn{10^{-3}} by default.}

\item{LIMderiv}{Convergence threshold of the Marquardt algorithm for the
gradient (see Details), \eqn{10^{-3}} by default.}

\item{print.times}{a logical parameter to print iteration process. Default
is TRUE.}
}
\value{
The following components are included in a 'trivPenalNL' object for each
model:

\item{b}{The sequence of the corresponding estimation of the coefficients
for the hazard functions (parametric or semiparametric), the random effects
variances and the regression coefficients.} \item{call}{The code used for
the model.} \item{formula}{The formula part of the code used for the
recurrent event part of the model.} \item{formula.terminalEvent}{The formula
part of the code used for the terminal event part of the model.}
\item{formula.KG}{The formula part of the code used for the longitudinal
part of the model, for the biomarker growth dynamics.} \item{formula.KD}{The
formula part of the code used for the longitudinal part of the model, for
the biomarker decline dynamics.} \item{coef}{The regression coefficients
(first for the recurrent events, then for the terminal event, then for the
biomarker growth and then for the biomarker decline.} \item{groups}{The
number of groups used in the fit.} \item{kappa}{The values of the smoothing
parameters in the penalized likelihood estimation corresponding to the
baseline hazard functions for the recurrent and terminal events.}
\item{logLikPenal}{The complete marginal penalized log-likelihood in the
semiparametric case.} \item{logLik}{The marginal log-likelihood in the
parametric case.} \item{n.measurements}{The number of biomarker observations
used in the fit.} \item{max_rep}{The maximal number of repeated measurements
per individual.} \item{n}{The number of observations in 'data' (recurrent
and terminal events) used in the fit.} \item{n.events}{The number of
recurrent events observed in the fit.} \item{n.deaths}{The number of
terminal events observed in the fit.} \item{n.iter}{The number of iterations
needed to converge.} \item{n.knots}{The number of knots for estimating the
baseline hazard function in the penalized likelihood estimation.}
\item{n.strat}{The number of stratum.}

\item{varH}{The variance matrix of all parameters (before positivity
constraint transformation for the variance of the measurement error, for
which the delta method is used).} \item{varHIH}{The robust estimation of the
variance matrix of all parameters.}

\item{xR}{The vector of times where both survival and hazard function of the
recurrent events are estimated. By default seq(0,max(time),length=99), where
time is the vector of survival times.} \item{lamR}{The array (dim=3) of
baseline hazard estimates and confidence bands (recurrent events).}
\item{survR}{The array (dim=3) of baseline survival estimates and confidence
bands (recurrent events).}

\item{xD}{The vector of times where both survival and hazard function of the
terminal event are estimated. By default seq(0,max(time),length=99), where
time is the vector of survival times.} \item{lamD}{The array (dim=3) of
baseline hazard estimates and confidence bands.} \item{survD}{The array
(dim=3) of baseline survival estimates and confidence bands.}
\item{medianR}{The value of the median survival and its confidence bands for the recurrent event.}
\item{medianD}{The value of the median survival and its confidence bands for the terminal event.}
\item{typeof}{The type of the baseline hazard function (0:"Splines",
"2:Weibull").} \item{npar}{The number of parameters.} \item{nvar}{The vector
of number of explanatory variables for the recurrent events, terminal event,
biomarker growth and biomarker decline.} \item{nvarRec}{The number of
explanatory variables for the recurrent events.} \item{nvarEnd}{The number
of explanatory variables for the terminal event.} \item{nvarKG}{The number
of explanatory variables for the biomarker growth.} \item{nvarKD}{The number
of explanatory variables for the biomarker decline.} \item{noVarRec}{The
indicator of absence of the explanatory variables for the recurrent events.}
\item{noVarEnd}{The indicator of absence of the explanatory variables for
the terminal event.} \item{noVarKG}{The indicator of absence of the
explanatory variables for the biomarker growth.} \item{noVarKD}{The
indicator of absence of the explanatory variables for the biomarker
decline.} \item{LCV}{The approximated likelihood cross-validation criterion
in the semiparametric case (with H minus the converged Hessian matrix, and
l(.) the full log-likelihood).\deqn{LCV=\frac{1}{n}(trace(H^{-1}_{pl}H) -
l(.))}} \item{AIC}{The Akaike information Criterion for the parametric
case.\deqn{AIC=\frac{1}{n}(np - l(.))}} \item{n.knots.temp}{The initial
value for the number of knots.} \item{shape.weib}{The shape parameter for
the Weibull hazard functions (the first element for the recurrences and the
second one for the terminal event).} \item{scale.weib}{The scale parameter
for the Weibull hazard functions (the first element for the recurrences and
the second one for the terminal event).}

\item{random.effects.pred}{ The empirical Bayes predictions of the random
effects (ie. using conditional posterior distributions).}
\item{global_chisq.testR}{The binary variable equals to 0 when no
multivariate Wald is given, 1 otherwise (for the recurrent part).}
\item{global_chisq.testT}{The binary variable equals to 0 when no
multivariate Wald is given, 1 otherwise (for the terminal part).}
\item{global_chisq.testKG}{The binary variable equals to 0 when no
multivariate Wald is given, 1 otherwise (for the biomarker growth).}
\item{global_chisq.testKD}{The binary variable equals to 0 when no
multivariate Wald is given, 1 otherwise (for the biomarker decline).}

\item{AG}{The logical value. Is Andersen-Gill model fitted? }

\item{B1}{The variance matrix of the random effects for the longitudinal
outcome.} \item{sigma2}{The variance of the frailty term (\eqn{\sigma_v}).}
\item{alpha}{The coefficient \eqn{\alpha} associated with the frailty
parameter in the terminal hazard function.} \item{ResidualSE}{The variance
of the measurement error.} \item{etaR}{The regression coefficients for the
link function \eqn{g(\cdot)}.} \item{etaT}{The regression coefficients for
the link function \eqn{h(\cdot)}.} \item{ne_re}{The number of random effects
b used in the fit.} \item{names.re}{The names of variables for the random
effects \eqn{\bold{b}_i}.} \item{link}{The name of the type of the link
functions.}

\item{leftCensoring}{The logical value. Is the longitudinal outcome
left-censored?} \item{leftCensoring.threshold}{For the left-censored
biomarker, the value of the left-censoring threshold used for the fit.}
\item{prop.censored}{The fraction of observations subjected to the
left-censoring.}

\item{methodGH}{The Gaussian quadrature method used in the fit.}
\item{n.nodes}{The number of nodes used for the Gaussian quadrature in the
fit.}

\item{K_G0}{Value of the estimate of the biomarker growth parameter.}
\item{K_D0}{Value of the estimate of the biomarker decay parameter.}
\item{lambda}{Value of the estimate of the biomarker resistance to drug.}
\item{y_0}{Value of the estimate of the biomarker intial level.}

\item{biomarker}{Name of the variable associated with the biomarker in the
data.} \item{time.biomarker}{Name of the variable associated with the time
of measurements of the biomarker in the data.} \item{dose}{Name of the
variable associated with the drug concentration in the data.}

\item{BoxCox}{The logical value. Is the BoxCox transformation applied for
the biomarker?} \item{BoxCox_parameter}{The value of the BoxCox
transformation parameter.}

\item{alpha_p.value}{p-value of the Wald test for the estimated coefficient
\eqn{\alpha}.} \item{sigma2_p.value}{p-value of the Wald test for the
estimated variance of the frailty term (\eqn{\sigma_v}).}
\item{etaR_p.value}{p-values of the Wald test for the estimated regression
coefficients for the link function \eqn{g(\cdot)}.}
\item{etaT_p.value}{p-values of the Wald test for the estimated regression
coefficients for the link function \eqn{h(\cdot)}.}
\item{y_0_p.value}{p-value of the Wald test for the estimated biomarker
intial level.} \item{K_G0_p.value}{p-value of the Wald test for the
estimated biomarker growth parameter.} \item{K_D0_p.value}{p-value of the
Wald test for the estimated biomarker decay parameter.}
\item{lambda_p.value}{p-value of the Wald test for the estimated biomarker
resistance to drug.} \item{beta_p.value}{p-values of the Wald test for the
estimated regression coefficients.}
}
\description{
{
\if{html}{Fit a non-linear trivariate joint model for a longitudinal biomarker,
recurrent events and a terminal event using a semiparametric penalized
likelihood estimation or a parametric estimation on the hazard functions.

The values y\out{<sub>i</sub>}(t) (i=1,...,N) for N subjects represent
the individual evolution of the biomarker e.g. tumor size expressed as the
sum of the longest diameters (SLD) of target lesions. The dynamics of the
biomarker are described by an ordinary differential equation (ODE) that
includes the effect of the natural net growth and the treatment effect:

{\figure{trivNLmodel1.png}{options: width="100\%"}}

The model includes the following parameters (using the interpretation of
tumor dynamics): exp(\eqn{K}\out{<sub>G,0</sub>}) the constant tumor growth rate,
exp(\eqn{K}\out{<sub>D,0</sub>}) the drug-induced tumor decline rate, \eqn{\lambda}
resistance effect to drug (exponential tumor decay change with time),
exp(y\out{<sub>0</sub>}) the initial level of the biomarker and d\out{<sub>i</sub>} is the
treatment concentration (e.g dose). The random effects \bold{b}\out{<sub>i</sub>}\out{<sup>T</sup>}
= (b\out{<sub>y0,i</sub>},b\out{<sub>G,i</sub>},b\out{<sub>D,i</sub>},b\out{<sub>\lambda,i</sub>})\out{<sup>T</sup>} are gaussian variables
with a diagonal covariance matrix \bold{B}\out{<sub>i</sub>}. In the trivariate model
we use the analytical solution of the equation with the population-based
approach of the non-linear mixed effects model. We can also assume a
transformation for the observations of the biomarker (one parameter Box-Cox
transformation) and we include a gaussian measurement error, for individual
i and observation k (k=1,...,n\out{<sub>i</sub>}),
\eqn{\epsilon}\out{<sub>ik</sub>} \out{&#126;} \bold{\eqn{N}}(0,\eqn{\sigma}\out{<sub>\epsilon</sub>}\out{<sup>2</sup>}).

The risks of the recurrent (r\out{<sub>ij</sub>}(.) the risk of the j\out{<sup>th</sup>}
event of the individual i) and terminal events (\eqn{\lambda}\out{<sub>i</sub>} the
risk of the event of the individual i) are represented by proportional
hazard risk models. The joint model is constructed assuming that the
processes are linked via a latent structure and includes the non-linear
mixed effects model for the longitudinal data:

{\figure{trivNLmodel2.png}{options: width="100\%"}}

where \bold{\eqn{X}}\out{<sub>G,i</sub>}(t), \bold{\eqn{X}}\out{<sub>D,i</sub>}(t),
\bold{\eqn{X}}\out{<sub>R,ij</sub>}(t) and \bold{\eqn{X}}\out{<sub>T,i</sub>}(t) are vectors of possible
time-varying fixed effects covariates and \bold{\eqn{\beta}}\out{<sub>G</sub>},
\bold{\eqn{\beta}}\out{<sub>D</sub>}, \bold{\eqn{\beta}}\out{<sub>R</sub>} and \bold{\eqn{\beta}}\out{<sub>T</sub>} are the
associated coefficients. The random effects \bold{b}\out{<sub>i</sub>} are independent
from the measurement error. The relationship between the biomarker and
recurrent events is explained via g(y\out{<sub>i</sub>}(t)) with coefficients
\bold{\eqn{\eta}}\out{<sub>R</sub>} and between the biomarker and terminal event is
explained via h(y\out{<sub>i</sub>}(t)) with coefficients \bold{\eqn{\eta}}\out{<sub>T</sub>}.
Currently, only one form of the functions g(.) and h(.)
is available: the random effects \bold{b}\out{<sub>i</sub>}. The frailty term
v\out{<sub>i</sub>} is gaussian with mean 0 and variance \eqn{\sigma}\out{<sub>v</sub>}. Together with
\bold{b}\out{<sub>i</sub>} constitutes the random effects of the model: 

{\figure{trivNLmodel3.png}{options: width="100\%"}}

Any combination of the random effects \bold{b}\out{<sub>i</sub>}, e.g.
\bold{b}\out{<sub>i</sub>}=b\out{<sub>y0,i</sub>} or \bold{b}\out{<sub>i</sub>} =
\{b\out{<sub>G,i</sub>},b\out{<sub>D,i</sub>},b\out{<sub>\lambda,i</sub>}\} can be chosen for the model.

We consider that the longitudinal outcome can be a subject to a
quantification limit, i.e. some observations, below a level of detection
s cannot be quantified (left-censoring).
}
\if{latex}{Fit a non-linear trivariate joint model for a longitudinal biomarker,
recurrent events and a terminal event using a semiparametric penalized
likelihood estimation or a parametric estimation on the hazard functions.

The values \eqn{y_i(t)} (\eqn{i=1,\ldots,N}) for \eqn{N} subjects represent
the individual evolution of the biomarker e.g. tumor size expressed as the
sum of the longest diameters (SLD) of target lesions. The dynamics of the
biomarker are described by an ordinary differential equation (ODE) that
includes the effect of the natural net growth and the treatment effect:

\deqn{\left\{ \begin{array}{ll}
\frac{dy_{i}(t)}{dt}&=\exp(K_{G,0}+b_{G,i}+\bold{X}_{G,i}(t)^\top\bold{\beta}_G)y_{i}(t)\\
&-d_i\exp(K_{D,0}+b_{D,i}-t\times\exp(\lambda+b_{\lambda,i})+\bold{X}_{D,i}(t)^\top\bold{\beta}_D)y_{i}(t)\\
y_{i}(0)&=\exp(y_0+b_{y_0,i}) \\ \end{array}, \right. }

The model includes the following parameters (using the interpretation of
tumor dynamics): \eqn{\exp(K_{G,0})} the constant tumor growth rate,
\eqn{\exp(K_{D,0})} the drug-induced tumor decline rate, \eqn{\lambda}
resistance effect to drug (exponential tumor decay change with time),
\eqn{\exp(y_0)} the initial level of the biomarker and \eqn{d_i} is the
treatment concentration (e.g dose). The random effects \eqn{\bold{b}_i^\top
= (b_{y_0,i},b_{G,i},b_{D,i},b_{\lambda,i})^\top} are gaussian variables
with a diagonal covariance matrix \eqn{\bold{B}_1}. In the trivariate model
we use the analytical solution of the equation with the population-based
approach of the non-linear mixed effects model. We can also assume a
transformation for the observations of the biomarker (one parameter Box-Cox
transformation) and we include a gaussian measurement error, for individual
\eqn{i} and observation \eqn{k} (\eqn{k=1,\ldots,n_i}),
\eqn{\epsilon_{ik}\sim N(0,\sigma_{\epsilon}^2)}.

The risks of the recurrent (\eqn{r_{ij}(\cdot)} the risk of the \eqn{j}-th
event of the individual \eqn{i}) and terminal events (\eqn{\lambda_{i}} the
risk of the event of the individual \eqn{i}) are represented by proportional
hazard risk models. The joint model is constructed assuming that the
processes are linked via a latent structure and includes the non-linear
mixed effects model for the longitudinal data:

\deqn{\left\{ \begin{array}{ll}
y(t_{ik})&=\exp[y_0+b_{y_0,i}+t_{ik}\times\exp(K_{G,0}+b_{G,i}+\bold{X}_{G,i}(t)^\top\bold\beta_{G})\\
&+d_i\times
\exp(K_{D,0}+b_{D,i}-\lambda-b_{\lambda,i}+\bold{X}_{D,i}(t)^\top\bold{\beta}_{D})\\
&\times(\exp(-\exp(\lambda+b_{\lambda,i})t_{ik})-1)]+\epsilon_{ik}\\
r_{ij}(t|\bold{b}_i)&=r_0(t)\exp(v_i+\bold{X}_{Rij}(t)^\top\bold{\beta}_R+g(y_i(t))^\top
\bold{\eta}_R ) \\ \lambda_i(t|\bold{b}_i)&=\lambda_0(t)\exp(\alpha
v_i+\bold{X}_{Ti}(t)^\top\bold{\beta}_T+h(y_i(t))^\top \bold{\eta}_T ) \\
\end{array} \right. }

where \eqn{\bold{X}_{G,i}(t)}, \eqn{\bold{X}_{D,i}(t)},
\eqn{\bold{X}_{R,ij}(t)} and \eqn{\bold{X}_{T,i}(t)} are vectors of possible
time-varying fixed effects covariates and \eqn{\bold{\beta}_G},
\eqn{\bold{\beta}_D}, \eqn{\bold{\beta}_R} and \eqn{\bold{\beta}_T} are the
associated coefficients. The random effects \eqn{\bold{b}_i} are independent
from the measurement error. The relationship between the biomarker and
recurrent events is explained via \eqn{g(y_i(t))} with coefficients
\eqn{\bold{\eta}_R} and between the biomarker and terminal event is
explained via \eqn{h(y_i(t))} with coefficients \eqn{\bold{\eta}_T}.
Currently, only one form of the functions \eqn{g(\cdot)} and \eqn{h(\cdot)}
is available: the random effects \eqn{\bold{b}_i}. The frailty term
\eqn{v_i} is gaussian with mean 0 and variance \eqn{\sigma_v}. Together with
\eqn{\bold{b}_i} constitutes the random effects of the model: \deqn{
\bold{u}_i=\left(\begin{array}{c} \bold{b}_{i}\\v_i \\ \end{array}\right)
\sim \mathcal{N}\left(\bold{0}, \left(\begin{array} {cc} \bold{B}_1&\bold{0}
\\ \bold{0} & \sigma_v^{2}\\\end{array}\right)\right), }

Any combination of the random effects \eqn{\bold{b}_i}, e.g.
\eqn{\bold{b}_i=b_{y_0,i}} or \eqn{\bold{b}_i =
\{b_{G,i},b_{D,i},b_{\lambda,i}\}} can be chosen for the model.

We consider that the longitudinal outcome can be a subject to a
quantification limit, i.e. some observations, below a level of detection
\eqn{s} cannot be quantified (left-censoring).}
}
}
\details{
{

Typical usage for the joint model
\preformatted{trivPenalNL(Surv(time,event)~cluster(id) + var1 + var2 +
terminal(death), formula.terminalEvent =~ var1 + var3, biomarker =
"biomarker.name", dose = "dose.name", time.biomarker = "time", formula.KG ~
var1, formula.KD ~ var2, data, data.Longi, ...)}

The method of the Gauss-Hermite quadrature for approximations of the
multidimensional integrals, i.e. length of \code{random} more than 2, can be
chosen among the standard (non-adaptive) and pseudo-adaptive in which the
quadrature points are transformed using the information from the fitted
mixed-effects model for the biomarker (Rizopoulos 2012) or multivariate
non-adaptive procedure proposed by Genz et al. 1996 and implemented in
FORTRAN subroutine HRMSYM.  The choice of the method is important for
estimations. The standard non-adaptive Gauss-Hermite quadrature
(\code{"Standard"}) with a specific number of points gives accurate results
but can be time consuming.  The pseudo-adaptive quadrature uses transformed
quadrature points to center and scale the integrand by utilizing estimates
of the random effects from an appropriate non-linear mixed-effects model
(this transformation does not include the frailty in the trivariate model,
for which the standard method, with 20 quadrature points, is used). This
method enables using less quadrature points while preserving the estimation
accuracy and thus lead to a better computational time.

NOTE. Data frames \code{data} and \code{data.Longi} must be consistent.
Names and types of corresponding covariates must be the same, as well as the
number and identification of individuals.
}
}
\note{
It is recommended to initialize the parameter values using the results
from a corresponding reduced model (\code{frailtyPenal} for the recurrent
and terminal part). See example.

Estimations of models with more than three random effects can be very long.
}
\examples{


\dontrun{

###--- Non-linear trivariate joint model for longitudinal data, ---###
###--- recurrent events and a terminal event ---###

data(colorectal)
data(colorectalLongi)

# No information on dose - creation of a dummy variable 
colorectalLongi$dose <- 1


# Parameters initialisation - estimation of a simplified model
# with two random effects (a frailty term and a random effect 
# related to biomarker growth (KG))
initial.model <- trivPenalNL(Surv(time0, time1, new.lesions) ~ cluster(id)
 + age + treatment + terminal(state), formula.terminalEvent =~ age + treatment, 
 biomarker = "tumor.size", formula.KG ~ 1, formula.KD ~ treatment, dose = "dose",
 time.biomarker = "year", data = colorectal, data.Longi =colorectalLongi, 
 random = "KG", id = "id", recurrentAG = TRUE, n.knots = 5, kappa = c(0.01, 2),
 method.GH = "Pseudo-adaptive")


# Trivariate joint model with initial values for parameters
# (computation takes around 40 minutes)

model <- trivPenalNL(Surv(time0, time1, new.lesions) ~ cluster(id) + age + treatment
 + terminal(state), formula.terminalEvent =~ age + treatment, biomarker = "tumor.size",
 formula.KG ~ 1, formula.KD ~ treatment, dose = "dose", time.biomarker = "year", 
 data = colorectal, data.Longi =colorectalLongi, random = c("y0", "KG"), id = "id", 
 init.B = c(-0.22, -0.16, -0.35, -0.19, 0.04, -0.41, 0.23), init.Alpha = 1.86,
 init.Eta = c(0.5, 0.57, 0.5, 2.34), init.Biomarker = c(1.24, 0.81, 1.07, -1.53),
 recurrentAG = TRUE, n.knots = 5, kappa = c(0.01, 2), method.GH = "Pseudo-adaptive")

}


}
\references{
A. Krol, C. Tournigand, S. Michiels and V. RondeauS (2018).
Multivariate joint frailty model for the analysis of nonlinear tumor
kinetics and dynamic predictions of death. \emph{Statistics in Medicine}.

A. Krol, L. Ferrer, JP. Pignon, C. Proust-Lima, M. Ducreux, O. Bouche, S.
Michiels, V. Rondeau (2016). Joint Model for Left-Censored Longitudinal
Data, Recurrent Events and Terminal Event: Predictive Abilities of Tumor
Burden for Cancer Evolution with Application to the FFCD 2000-05 Trial.
\emph{Biometrics} \bold{72}(3) 907-16.

D. Rizopoulos (2012). Fast fitting of joint models for longitudinal and
event time data using a pseudo-adaptive Gaussian quadrature rule.
\emph{Computational Statistics and Data Analysis} \bold{56}, 491-501.

L. Claret, P. Girard, P.M. Hoff, E. Van Cutsem, K.P. Zuideveld, K. Jorga, J.
Fagerberg, R Bruno (2009). Model-based prediction of phase III overall
survival in colorectal cancer on the basis of phase II tumor dynamics.
\emph{Journal of Clinical Oncology} \bold{27}(25), 4103-8.
}
\seealso{
\code{\link{plot.trivPenalNL}},\code{\link{print.trivPenalNL}},\code{\link{summary.trivPenalNL}}
}
\keyword{models}
